# 0.7
- Restart from scratch
- Restrict cross origin resource sharing
- Define EnumeratedBase, RandomBase

# 0.6
- Replace emphasis with highlighted

# 0.5
- Add base_url
- Add test fixtures for downstream packages
- Bundle css and js from website.dependencies with cache busting
- Define get_record_id
- Let templates override page_author, copyright_year, copyright_author
- Replace expiration_time with expiration_time_in_seconds

# 0.4
- Add confirmation_modal
- Add page_description
- Fix Python 3 compatibility

# 0.3
- Add extensible command line script

# 0.2
- Replace mako with jinja2

# 0.1
- Add posts scaffold
